import { z } from 'zod';
export type ContractData = z.infer<typeof data>;
export type ContractTemplate = z.infer<typeof template>;
declare const template: z.ZodObject<{
    description: z.ZodString;
    agent: z.ZodOptional<z.ZodString>;
    members: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
}, "strip", z.ZodTypeAny, {
    description: string;
    agent?: string | undefined;
    members?: string[] | undefined;
}, {
    description: string;
    agent?: string | undefined;
    members?: string[] | undefined;
}>;
declare const data: z.ZodObject<{
    info: z.ZodObject<{
        description: z.ZodString;
        admin: z.ZodString;
        agent: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        description: string;
        admin: string;
        agent: string;
    }, {
        description: string;
        admin: string;
        agent: string;
    }>;
    meta: z.ZodObject<{
        block_id: z.ZodString;
        open_txid: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        close_txid: z.ZodUnion<[z.ZodString, z.ZodNull]>;
    }, "strip", z.ZodTypeAny, {
        block_id: string;
        open_txid: string | null;
        close_txid: string | null;
    }, {
        block_id: string;
        open_txid: string | null;
        close_txid: string | null;
    }>;
    room: z.ZodObject<{
        secret: z.ZodString;
        nonce: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        pubkey: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        hash: z.ZodUnion<[z.ZodString, z.ZodNull]>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string | null;
        hash: string | null;
        secret: string;
        nonce: string | null;
    }, {
        pubkey: string | null;
        hash: string | null;
        secret: string;
        nonce: string | null;
    }>;
    status: z.ZodEnum<["draft", "published", "active", "disputed", "closed"]>;
    members: z.ZodArray<z.ZodString, "many">;
    contract_id: z.ZodString;
    revision: z.ZodNumber;
    created_at: z.ZodDate;
    updated_at: z.ZodDate;
}, "strip", z.ZodTypeAny, {
    status: "draft" | "published" | "active" | "disputed" | "closed";
    info: {
        description: string;
        admin: string;
        agent: string;
    };
    meta: {
        block_id: string;
        open_txid: string | null;
        close_txid: string | null;
    };
    room: {
        pubkey: string | null;
        hash: string | null;
        secret: string;
        nonce: string | null;
    };
    members: string[];
    contract_id: string;
    revision: number;
    created_at: Date;
    updated_at: Date;
}, {
    status: "draft" | "published" | "active" | "disputed" | "closed";
    info: {
        description: string;
        admin: string;
        agent: string;
    };
    meta: {
        block_id: string;
        open_txid: string | null;
        close_txid: string | null;
    };
    room: {
        pubkey: string | null;
        hash: string | null;
        secret: string;
        nonce: string | null;
    };
    members: string[];
    contract_id: string;
    revision: number;
    created_at: Date;
    updated_at: Date;
}>;
export declare const ContractSchema: {
    data: z.ZodObject<{
        info: z.ZodObject<{
            description: z.ZodString;
            admin: z.ZodString;
            agent: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            description: string;
            admin: string;
            agent: string;
        }, {
            description: string;
            admin: string;
            agent: string;
        }>;
        meta: z.ZodObject<{
            block_id: z.ZodString;
            open_txid: z.ZodUnion<[z.ZodString, z.ZodNull]>;
            close_txid: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        }, "strip", z.ZodTypeAny, {
            block_id: string;
            open_txid: string | null;
            close_txid: string | null;
        }, {
            block_id: string;
            open_txid: string | null;
            close_txid: string | null;
        }>;
        room: z.ZodObject<{
            secret: z.ZodString;
            nonce: z.ZodUnion<[z.ZodString, z.ZodNull]>;
            pubkey: z.ZodUnion<[z.ZodString, z.ZodNull]>;
            hash: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        }, "strip", z.ZodTypeAny, {
            pubkey: string | null;
            hash: string | null;
            secret: string;
            nonce: string | null;
        }, {
            pubkey: string | null;
            hash: string | null;
            secret: string;
            nonce: string | null;
        }>;
        status: z.ZodEnum<["draft", "published", "active", "disputed", "closed"]>;
        members: z.ZodArray<z.ZodString, "many">;
        contract_id: z.ZodString;
        revision: z.ZodNumber;
        created_at: z.ZodDate;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        status: "draft" | "published" | "active" | "disputed" | "closed";
        info: {
            description: string;
            admin: string;
            agent: string;
        };
        meta: {
            block_id: string;
            open_txid: string | null;
            close_txid: string | null;
        };
        room: {
            pubkey: string | null;
            hash: string | null;
            secret: string;
            nonce: string | null;
        };
        members: string[];
        contract_id: string;
        revision: number;
        created_at: Date;
        updated_at: Date;
    }, {
        status: "draft" | "published" | "active" | "disputed" | "closed";
        info: {
            description: string;
            admin: string;
            agent: string;
        };
        meta: {
            block_id: string;
            open_txid: string | null;
            close_txid: string | null;
        };
        room: {
            pubkey: string | null;
            hash: string | null;
            secret: string;
            nonce: string | null;
        };
        members: string[];
        contract_id: string;
        revision: number;
        created_at: Date;
        updated_at: Date;
    }>;
    members: z.ZodArray<z.ZodString, "many">;
    ref: z.ZodObject<{
        contract_id: z.ZodString;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        contract_id: string;
        updated_at: Date;
    }, {
        contract_id: string;
        updated_at: Date;
    }>;
    signature: z.ZodString;
    template: z.ZodObject<{
        description: z.ZodString;
        agent: z.ZodOptional<z.ZodString>;
        members: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        description: string;
        agent?: string | undefined;
        members?: string[] | undefined;
    }, {
        description: string;
        agent?: string | undefined;
        members?: string[] | undefined;
    }>;
};
export {};
//# sourceMappingURL=contract.d.ts.map